from typing import Optional
from pydantic import BaseModel


class UserSignupForm(BaseModel):
    username: str
    email: str
    password: str

    invite_code: Optional[str] = None

